# RentcastPropertyRecords200ResponseInnerPropertyTaxes


## Properties

Name | Type | Description | Notes
------------ | ------------- | ------------- | -------------
**var_2020** | [**RentcastPropertyRecords200ResponseInnerPropertyTaxes2020**](RentcastPropertyRecords200ResponseInnerPropertyTaxes2020.md) |  | [optional] 
**var_2021** | [**RentcastPropertyRecords200ResponseInnerPropertyTaxes2021**](RentcastPropertyRecords200ResponseInnerPropertyTaxes2021.md) |  | [optional] 
**var_2022** | [**RentcastPropertyRecords200ResponseInnerPropertyTaxes2022**](RentcastPropertyRecords200ResponseInnerPropertyTaxes2022.md) |  | [optional] 
**var_2023** | [**RentcastPropertyRecords200ResponseInnerPropertyTaxes2023**](RentcastPropertyRecords200ResponseInnerPropertyTaxes2023.md) |  | [optional] 
**var_2024** | [**RentcastPropertyRecords200ResponseInnerPropertyTaxes2024**](RentcastPropertyRecords200ResponseInnerPropertyTaxes2024.md) |  | [optional] 

## Example

```python
from rentcast_client.models.rentcast_property_records200_response_inner_property_taxes import RentcastPropertyRecords200ResponseInnerPropertyTaxes

# TODO update the JSON string below
json = "{}"
# create an instance of RentcastPropertyRecords200ResponseInnerPropertyTaxes from a JSON string
rentcast_property_records200_response_inner_property_taxes_instance = RentcastPropertyRecords200ResponseInnerPropertyTaxes.from_json(json)
# print the JSON string representation of the object
print(RentcastPropertyRecords200ResponseInnerPropertyTaxes.to_json())

# convert the object into a dict
rentcast_property_records200_response_inner_property_taxes_dict = rentcast_property_records200_response_inner_property_taxes_instance.to_dict()
# create an instance of RentcastPropertyRecords200ResponseInnerPropertyTaxes from a dict
rentcast_property_records200_response_inner_property_taxes_from_dict = RentcastPropertyRecords200ResponseInnerPropertyTaxes.from_dict(rentcast_property_records200_response_inner_property_taxes_dict)
```
[[Back to Model list]](../README.md#documentation-for-models) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to README]](../README.md)


